#include "absUnitPool.h"

#include "stl.h"

#include <map>
#include <string>
#include <utility>

namespace absUnitPool
{

AbsUnitPool::AbsUnitPool(const AbsUnit& defaultUnit)
  : defaultUnit_(new AbsUnit(defaultUnit))
{
  absUnits_.insert(std::make_pair(defaultUnit.name, defaultUnit_));
}

void AbsUnitPool::addAbsUnit(const AbsUnit& toAdd)
{
  absUnits_.insert(std::make_pair(toAdd.name,
                                  AbsUnitPtr(new AbsUnit(toAdd))));
}

AbsUnitPtr AbsUnitPool::getDefaultUnit() const
{
  return defaultUnit_;
}

std::vector<std::string> AbsUnitPool::getAbsUnitNames() const
{
  return stl::getKeys(absUnits_);
}

AbsUnitPtr AbsUnitPool::getAbsUnit(const std::string& name) const
{
  AbsUnitPtr result;
  std::map<std::string, AbsUnitPtr>::const_iterator nameAndPtr =
    absUnits_.find(name);
  if (nameAndPtr != absUnits_.end())
    result = nameAndPtr->second;
  return result;
}

bool AbsUnitPool::getAbsUnitAmount(const std::string& name,
                                   numbers::Number& amount) const
{
  AbsUnitPtr unitPtr = getAbsUnit(name);
  if (unitPtr.get() == 0)
    return false;
  amount = unitPtr->value;
  return true;
}

AbsUnitPool::AbsUnitPool() {}


} // namespace absUnitPool
