#ifndef ABSUNITPOOL_H
#define ABSUNITPOOL_H

#include "numbers.h"
#include "pointers.h"
#include "serializer_fwd.h"

#include <map>
#include <string>
#include <vector>

namespace absUnitPool
{

struct AbsUnit
{
  std::string     name;
  numbers::Number value;
};

typedef pointers::Shared<const AbsUnit> AbsUnitPtr;

/** A shared pool for absolute units.
 *
 * This solves a problem similar to the one addressed by
 * StrPool, although the memory savings here are not nearly
 * as large.
 */
class AbsUnitPool
{
public:
  explicit AbsUnitPool(const AbsUnit& defaultUnit);
  void addAbsUnit(const AbsUnit& toAdd);

  AbsUnitPtr getDefaultUnit() const;

  /** Get the names of all the absolute units in this pool.
   * These names are not sorted.
   */
  std::vector<std::string> getAbsUnitNames() const;
  AbsUnitPtr getAbsUnit(const std::string& name) const;

  /** Get the amount corresponding to a particular absolute
   * unit name.
   *
   * \param name Name of the unit you wish to retrieve.
   * \param amount The result is returned here.
   * \return True if the unit with the given name is in the
   * pool; False if it is not in the pool. If it is not in
   * the pool, then the value of amount is unchanged.
   */
  bool getAbsUnitAmount(const std::string& name,
                        numbers::Number& amount) const;

  friend class serializer::Loader;
  friend class serializer::Saver;

private:
  /** Allows the serialization loader to create an empty
   * AbsUnitPool.
   */
  AbsUnitPool();
  std::map<std::string, AbsUnitPtr> absUnits_;
  AbsUnitPtr defaultUnit_;
};

} // namespace absUnitPool

#endif
