#include "comm.h"
#include "errors.h"

#include <iostream>
#include <string>
#include <vector>

#include <errno.h>
#include <stdlib.h>
#include <string.h>

namespace
{
  std::string getCurrDir()
  {
    unsigned int size = 100;
    while (1)
    {
      std::vector<char> buffer(size);
      if (getcwd(&buffer[0], size) == &buffer[0])
        return std::string(&buffer[0]);

      if (errno != ERANGE)
      {
        std::cerr << "pantry: error: cannot determine current "
                  << "working directory: "
                  << strerror(errno) << '\n';
        exit(1);
      }
      size *= 2;
    }
  }
} // unnamed namespace

int main(int argc, char** argv)
{
  std::string currDir = getCurrDir();

  std::vector<std::string> args(argv, argv + argc);
  try
  {
    comm::Request request(currDir, args);
    comm::ClientSocket clientSocket(request);
    comm::Response response = clientSocket.getResponse();
    std::cout << response.getOutput();
    std::cerr << response.getErrors();
    return response.getReturnCode();
  }
  catch (errors::Pantry& e)
  {
    std::cerr << "pantry: error: " << e.getBriefMessage() << '\n';
    return 1;
  }
}
