#ifndef COLLECTIONS_H
#define COLLECTIONS_H

#include "food.h"

#include "errors.h"

#include <list>
#include <map>
#include <string>
#include <vector>

namespace collections
{

typedef std::vector<std::string> StringVec;
typedef std::list<food::Food> FoodList;
typedef std::map<std::string, FoodList > Collections;
typedef std::vector<const Collections::value_type*> CollectionConstPtrs;
typedef std::vector<Collections::value_type*> CollectionPtrs;
typedef std::map<std::string, bool> Unsaved;
typedef std::vector<food::Food*> FoodPtrs;
typedef std::vector<const food::Food*> FoodConstPtrs;
typedef std::vector<food::Food> FoodVec;
typedef std::map<std::string, FoodVec > FoodVecMap;

CollectionConstPtrs
getCollectionPtrs(const Collections& collections,
                  const StringVec& abbreviations);
CollectionPtrs
getCollectionPtrs(Collections& collections,
                  const StringVec& abbreviations);

FoodPtrs getFoodPtrs(Collections& collections);
FoodConstPtrs getFoodPtrs(const Collections& collections);

FoodConstPtrs
getFoodPtrs(const FoodVecMap& foodVecMap);

class BadAbbreviationError : public errors::NonFatal
{
public:
    BadAbbreviationError(const std::string& badAbbrev,
                         const StringVec& matches);
    std::string getBriefMessage() const;

private:
    const std::string badAbbrev_;
    const StringVec matches_;
};

} // namespace collections

#endif
