#ifndef INPUTS_H
#define INPUTS_H

#include "adder.h"
#include "changer.h"
#include "collections.h"
#include "errors.h"
#include "parser.h"
#include "reporter.h"
#include "searcher.h"

#include <string>
#include <vector>

namespace inputs
{

parser::Result getParsed(const std::vector<std::string>& args);

struct Inputs
{
  Inputs(const parser::Result& args,
         const db::Db& db);

  bool doOpen;
  std::string openFilename;

  bool doRead;
  std::string readFilename;

  bool doClose;
  bool doSave;
  bool doSaveAs;
  std::string saveAsFilename;

  bool doQuit;
  bool doStatus;

  bool doCreate;

  bool doHelp;
  bool doVersion;
  bool doCopyright;

  searcher::Searcher             searcher;
  changer::Changer               changer;

  bool doEdit;
  bool doDelete;

  adder::Adder                   adder;
  reporter::Reporter             reporter;
};

class EmptyFilenameError : public errors::NonFatal
{
public:
  std::string getBriefMessage() const;
};

} // namespace inputs

#endif
