#ifndef META_H
#define META_H

#include "config.h"

#include <string>

namespace meta
{

const std::string HELP =

"Usage: pantry [options] COLLECTION...\n"
"\n"
"FILE AND SERVER CONTROL\n"
"    --open file\n"
"	Close current file and open new one\n"
"    --read file\n"
"       Append contents of file to currently open file\n"
"    --close\n"
"	Close currently open file\n"
"    --save\n"
"	Save contents of current file\n"
"    --save-as filename\n"
"	Save current file under different name\n"
"    --quit\n"
"	Shut down server\n"
"    --status\n"
"       Current server status\n"
"\n"
"FOOD SELECTION\n"
"    -s {trait} regexp, --search {trait} regexp\n"
"        Select foods whose trait matches regexp\n"
"\n"
"    Where {trait} is any one of:\n"
"	name\n"
"	group\n"
"	quantity\n"
"	unit\n"
"	date\n"
"	meal\n"
"	comment\n"
"	order\n"
"	refuse\n"
"	percent-refuse\n"
"	yield\n"
"	instructions\n"
"\n"
"CHANGE FOOD TRAITS\n"
"    -c {trait} string, --change {trait} string\n"
"        Change trait so that it matches string\n"
"        (quantity, percent-refuse: must evaluate to a number;\n"
"        unit: regular expression)\n"
"\n"
"    --by-nut nut-name qty\n"
"        set quantity of food so amount of nut-name = qty\n"
"    -r, --refuse          \n"
"        reduce qty by percent refuse\n"
"\n"
"CHANGING NUTRIENTS, AVAILABLE UNITS, AND INGREDIENTS\n"
"Each option may appear multiple times; all appearances are used.\n"
"\n"
"    --change-nut unit-name value\n"
"        change nutrient value\n"
"    --rename-nut pattern new-name\n"
"        rename nutrient matching pattern to new-name\n"
"    --delete-nuts regexp\n"
"        delete nutrients matching regexp\n"
"    --change-avail-unit unit-name value\n"
"        change available unit value\n"
"    --rename-avail-unit pattern new-name\n"
"        rename available unit matching pattern to new-name\n"
"    --delete-avail-units regexp\n"
"        delete available units matching regexp\n"
"    --add-ingredients collection\n"
"        add ingredients from collection\n"
"    --delete-ingredients regexp\n"
"        delete ingredients whose name matches regexp\n"
"\n"
"SEARCH AND EDIT OPTIONS\n"
"If option appears multiple times, only the last one is used.\n"
"\n"
"    -i, --ignore-case\n"
"        make searches case insensitive\n"
"    -x, --exact-match\n"
"        searches must match exactly (no regexp)\n"
"    --edit\n"
"        Edit foods in place\n"
"    --delete\n"
"        delete matching foods\n"
"    --create\n"
"        Make a new food from scratch\n"
"    --limit number\n"
"	Limit number of foods in buffer to number\n"
"\n"
"REPORTING\n"
"Options may appear multiple times; all appearances are used.\n"
"\n"
"    -p REPORT, --print REPORT\n"
"        print REPORT, where REPORT is one of:\n"
"            name - name trait\n"
"            info - all traits except name and recipe-related\n"
"            recipe - recipe-related traits\n"
"            units - available units\n"
"            paste - name and available units for cut-and-paste\n"
"            groups - summary of group traits\n"
"            nuts - all nutrients\n"
"            Nuts - sum of all nutrients in the buffer\n"
"            goals - all goal nutrients\n"
"            Goals - sum of all goal nutrients in the buffer\n"
"            blank - a blank line\n"
"\n"
"    -k {trait}, --key {trait}\n"
"        Sort by trait\n"
"        (first letter lowercase: ascending order;\n"
"        first letter uppercase: descending order)\n"
"\n"
"    -g nut-name goal, --goal nut-name goal\n"
"        Add nutrient nut-name to nutrient list with goal\n"
"\n"
"    -l {trait} string, --list {trait} string\n"
"        Append string to list of {trait} sort orders \n"
"\n"
"ADDING RESULTS TO FILES\n"
"Options may appear multiple times; all appearances are used.\n"
"\n"
"    -a COLLECTION, --add COLLECTION\n"
"        add results to COLLECTION\n"
"    -o, --auto-order\n"
"        automatically increment order trait when adding foods\n"
"\n"
"META\n"
"Options may appear multiple times; all appearances are used.\n"
"\n"
"    -h, --help\n"
"        show this help message and exit\n"
"    -v, --version\n"
"        Print version information and exit\n"
"    --copyright\n"
"        Print copyright and license information and exit\n"
"\n"
"Pantry home page: http://www.smileystation.com/pantry\n"
"Report bugs to omari@smileystation.com.\n";

// don't call this version (in all caps) as this will conflict with
// a macro created by GNU build system
const std::string VER = 
"Pantry, command-line nutrient analysis.\n"
"Version "
PACKAGE_VERSION
", released "
RELEASE_DATE
".\n";

const std::string COPYRIGHT =
"Software and documentation is copyright "
YEARS 
" Omari Norman.\n"
"\n"
"Permission is hereby granted, free of charge, to any person obtaining a copy\n"
"of this software and associated documentation files (the \"Software\"), to deal\n"
"in the Software without restriction, including without limitation the rights\n"
"to use, copy, modify, merge, publish, distribute, sublicense, and/or sell\n"
"copies of the Software, and to permit persons to whom the Software is\n"
"furnished to do so, subject to the following conditions:\n"
"\n"
"The above copyright notice and this permission notice shall be included in\n"
"all copies or substantial portions of the Software.\n"
"\n"
"THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n"
"IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\n"
"FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\n"
"AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\n"
"LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\n"
"OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\n"
"THE SOFTWARE.\n"
"\n"
"Nutrient data in the starter_database file is derived from:\n"
"U.S. Department of Agriculture, Agricultural Research Service. 2008.\n"
"USDA National Nutrient Database for Standard Reference, Release 21.\n"
"Nutrient Data Laboratory Home Page,\n"
"http://www.ars.usda.gov/ba/bhnrc/ndl\n"
"This data is in the public domain and there is no copyright, see\n"
"http://www.ars.usda.gov/Main/docs.htm?docid=6233#copyright\n";

} // namespace meta

#endif
