#ifndef NUMBERS_H
#define NUMBERS_H

#include "errors.h"
#include "serializer_fwd.h"

#include <string>

namespace numbers
{

class Number
{
public:
  Number();
  explicit Number(double value);
  explicit Number(const std::string& value);
  double getValue() const;
  std::string getString() const;
  bool isZero() const;
  
  friend class serializer::Loader;
  friend class serializer::Saver;

private:
  double value_;
};

class Percent
{
public:
  Percent();
  explicit Percent(int value);
  explicit Percent(const std::string& value);
  int getValue() const;
  std::string getString() const;

  friend class serializer::Loader;
  friend class serializer::Saver;

private:
  int value_;
};

class StrNumber
{
public:
  StrNumber();
  explicit StrNumber(double value);
  explicit StrNumber(const std::string& value);
  double getValue() const;
  std::string getString() const;

  friend class serializer::Loader;
  friend class serializer::Saver;

private:
  std::string string_;
};

/** A string cannot be converted to a number.
 */
class Unconvertible : public errors::NonFatal
{
public:
    /** ctor.
     * \param badString the string that cannot be converted to a
     * number.
     */
    Unconvertible(const std::string& badString);
    std::string getBriefMessage() const;
    
private:
    std::string badString_;
};

/** A number is negative that isn't allowed to be negative.
 */
class NegativeNumber : public errors::NonFatal 
{
public:
    /** ctor.
     * \param badNumber The offending negative number.
     */
    NegativeNumber(const double& badNumber);
    std::string getBriefMessage() const;

private:
    double badNumber_;
};

/** A number for a percent was not between 0 and 100.
 */
class NonPercent : public errors::NonFatal
{
public:
    /** ctor.
     * \param badNumber The offending number.
     */
    NonPercent(const double& badNumber);
    std::string getBriefMessage() const;

private:
    double badNumber_;
};

} // namespace numbers

#endif
