#ifndef PREDICATE_H
#define PREDICATE_H

#include "errors.h"
#include "food.h"
#include "matchers.h"

#include <string>
#include <utility>
#include <vector>

namespace predicate {

typedef std::vector<std::pair<std::string, std::string> > StringPairs;

struct Regexps
{
  Regexps();
  Regexps(const StringPairs& traits, bool ignoreCase, bool exactMatch);
  matchers::MatcherVec     name;
  matchers::MatcherVec     group;
  matchers::MatcherVec     date;
  matchers::MatcherVec     meal;
  matchers::MatcherVec     comment;
  matchers::MatcherVec     order;
  matchers::MatcherVec     refDesc;
  matchers::MatcherVec     instructions;
  matchers::MatcherVec     qty;
  matchers::MatcherVec     pctRefuse;
  matchers::MatcherVec     yield;
  matchers::MatcherVec     unit;
};

class Predicate
{
public:
  Predicate(const Regexps& regexps);

  // default copy ctor and assignment operators are OK

  bool operator() (const food::Food& food) const;

private:
  Regexps regexps_;
  struct StrTraits
  {
    std::string name;
    std::string group;
    std::string date;
    std::string meal;
    std::string comment;
    std::string order;
    std::string refDesc;
    std::string instructions;
    std::string qty;
    std::string pctRefuse;
    std::string yield;
    std::string unit;
  };
  StrTraits getStrTraits(const food::Food& food) const;
};

/** Incorrect trait abbreviation specified for a search.
 */
class PredicateBadTraitAbbreviation : public errors::NonFatal
{
public:
  PredicateBadTraitAbbreviation(unsigned int nMatches,
                                const std::string& abbrev);
  std::string getBriefMessage() const;

private:
  unsigned int nMatches_;
  std::string abbrev_;
};

} // namespace predicate

#endif
