#ifndef SEARCHER_H
#define SEARCHER_H

#include "collections.h"
#include "predicate.h"

#include <list>
#include <map>
#include <string>
#include <utility>
#include <vector>

namespace searcher {

typedef std::vector<std::pair<std::string, std::string> > StringPairs;
typedef std::vector<std::string> StringVec;
typedef std::vector<std::list<food::Food>::iterator> SelectionsVec;
typedef std::map<std::string, SelectionsVec> SelectionsVecs;

class Searcher
{
public:
  Searcher(const StringPairs& searchPatterns,
           const std::pair<bool, std::string>& limit,
           bool ignoreCase,
           bool exactMatch,
           const std::vector<std::string>& toSearch);

  /** Get matches.
   *
   * Offers strong guarantee.
   */
  SelectionsVecs
  process(collections::Collections& collections) const;

private:
  predicate::Predicate predicate_;
  std::pair<bool, unsigned int> limit_;
  std::vector<std::string> toSearch_;
};

/** Invalid value used for limit option.
 */
struct Limit : public errors::NonFatal
{
    std::string getBriefMessage() const;
};

/** Attempted to search a collection for foods, but that collection
 * name not found.
 */
class CollectionNotFound : public errors::NonFatal
{
public:
    CollectionNotFound(const std::string& name);
    std::string getBriefMessage() const;

private:
    std::string name_;
};

} // namespace searcher

#endif
