#include "strPool.h"

#include "stl.h"

#include <map>
#include <utility>

namespace strPool
{

StrPtr StrPool::getStrPtr(const std::string& str)
{
  StrPtr result;
  std::map<std::string, StrPtr>::const_iterator strAndStrPtr =
    stringPtrMap_.find(str);
  if (strAndStrPtr != stringPtrMap_.end())
    result = strAndStrPtr->second;
  return result;
}

StrPtr StrPool::addToPool(const std::string& str)
{
  std::map<std::string, StrPtr>::const_iterator strAndStrPtr =
    stringPtrMap_.find(str);
  if (strAndStrPtr == stringPtrMap_.end())
  {
    StrPtr newStrPtr(new std::string(str));
    std::pair<std::map<std::string, StrPtr>::iterator, bool> insertResult =
      stringPtrMap_.insert(std::make_pair(str, newStrPtr));
    return insertResult.first->second;
  }
  else
    return strAndStrPtr->second;
}

void StrPool::removeUnusedStr(const std::string& str)
{
  std::map<std::string, StrPtr>::iterator strAndPtr =
    stringPtrMap_.find(str);
  if (strAndPtr != stringPtrMap_.end())
  {
    if (strAndPtr->second.unique())
      stringPtrMap_.erase(strAndPtr);
  }
}

void StrPool::cleanup()
{
  std::map<std::string, StrPtr>::iterator currIt = stringPtrMap_.begin();
  while (currIt != stringPtrMap_.end())
  {
    if (currIt->second.unique())
    {
      std::map<std::string, StrPtr>::iterator itToErase = currIt;
      ++currIt;
      stringPtrMap_.erase(itToErase);
    }
    else
      ++currIt;
  }
}

bool StrPool::inPool(const std::string& str) const
{
  std::map<std::string, StrPtr>::const_iterator strAndPtr =
    stringPtrMap_.find(str);
  return (strAndPtr != stringPtrMap_.end());
}

void StrPool::swap(StrPool& rhs)
{
  stringPtrMap_.swap(rhs.stringPtrMap_);
}

} // namespace strPool
