#include <algorithm>
#include <functional>
#include <iosfwd>
#include <string>
#include <vector>
#include <sstream>

namespace strings {

const std::string WHITESPACE(" \t\n\r\v");

// thanks to 
// http://groups.google.com/group/comp.lang.c++/msg/e19335f1c396d288
std::vector<std::string> explode (const std::string& inString,
        const std::string& separator);

std::vector<std::string> explode (const std::string& inString,
        const std::string& separator, int maxSplits);

std::string ltrim(const std::string& x,
                  const std::string& toTrim = WHITESPACE);
std::string rtrim(const std::string& x, 
                  const std::string& toTrim = WHITESPACE);
std::string trim (const std::string& x,
                  const std::string& toTrim = WHITESPACE);

bool startswith(const std::string& subject, const std::string& test);
bool endswith  (const std::string& subject, const std::string& test);

std::vector<std::string> 
matchAbbrev(const std::vector<std::string>& strings,
            const std::string& abbrev);

std::string replace(const std::string& subject,
                    char toReplace, 
                    const std::string& replacement);

/** Only guaranteed to work with ASCII.
 */
std::string capitalizeFirstLetter(const std::string&);
std::string firstLetterToLower(const std::string&);
std::string toLower(const std::string&);

template <class T>
bool stringify(const T& source, std::string& dest)
{
    std::ostringstream o;
    if (! (o << source))
        return false;
    dest = o.str();
    return true;
}

template <typename T>
bool deStringify(const std::string& source, T& dest)
{
    std::istringstream i(source);
    char c;
    i >> dest;
    if (i.fail() || i.get(c))
        return false;
    return true;
}

std::string pathJoin(const std::vector<std::string>& parts);
std::string pathJoin(const std::string& part1, const std::string& part2);
std::string getAbsoluteFilename(const std::string& relativeTo,
                                const std::string& filename);

} // namespace strings
